@@ -1,5 +1,5 @@
 PROFILE_FUNC_LIST = []
-from cookie import cookie
+from mypy import cookie
 
 import hotshot,hotshot.stats
 from os import getpid
@@ -177,4 +177,4 @@ def ProfileMiddleware(application):
                     result = "%s %s"%(result,so)
                 return result
         return application(request)
-    return _application
\ No newline at end of file
+    return _application
